@@ -51,13 +51,17 @@ package com.openexchange.guard.storage.file.osgi;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import com.openexchange.database.AssignmentFactory;
+import com.openexchange.filestore.DatabaseAccessProvider;
 import com.openexchange.filestore.FileStorageService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.storage.Storage;
 import com.openexchange.guard.storage.cache.FileCacheStorage;
 import com.openexchange.guard.storage.file.internal.FileStorageImpl;
 import com.openexchange.guard.storage.file.internal.LegacyFileStorageImpl;
+import com.openexchange.guard.storage.file.internal.SproxydDatabaseProvider;
 import com.openexchange.guard.storage.file.internal.SproxydStorageImpl;
 import com.openexchange.osgi.HousekeepingActivator;
 
@@ -68,6 +72,8 @@ import com.openexchange.osgi.HousekeepingActivator;
  */
 public class GuardFileStorageActivator extends HousekeepingActivator {
 
+    private static final String SPROXYD_FILESTORE = "com.openexchange.guard.storage.file.sproxydFilestore";
+
     /**
      * Initialises a new {@link GuardFileStorageActivator}.
      */
@@ -82,7 +88,8 @@ public class GuardFileStorageActivator extends HousekeepingActivator {
      */
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { GuardConfigurationService.class, FileCacheStorage.class, FileStorageService.class };
+        return new Class<?>[] { GuardConfigurationService.class, FileCacheStorage.class,
+            FileStorageService.class };
     }
 
     /*
@@ -102,7 +109,14 @@ public class GuardFileStorageActivator extends HousekeepingActivator {
         } else {
             switch (guardConfigService.getProperty(GuardProperty.fileStorageType)) {
                 case "sproxyd":
-                    registerService(Storage.class, new SproxydStorageImpl(this.getService(FileStorageService.class), "guard"));
+                    String fileStore = guardConfigService.getProperty(SPROXYD_FILESTORE);
+                    if (fileStore == null || fileStore.isEmpty()) {
+                        fileStore = "guard";
+                    }
+                    registerService(Storage.class, new SproxydStorageImpl(this.getService(FileStorageService.class), fileStore));
+                    trackService(GuardDatabaseService.class);
+                    trackService(AssignmentFactory.class);
+                    registerService(DatabaseAccessProvider.class, new SproxydDatabaseProvider(this));
                     break;
                 default:
                     registerService(Storage.class, new FileStorageImpl(this.getService(FileStorageService.class), guardConfigService.getProperty(GuardProperty.uploadDirectory)));
